<?php
/*
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2015 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_TB_VERSION_'))
	exit;

class StatsOrdersUnpaid extends ModuleGrid
{
	private $html = null;
	private $query = null;
	private $columns = null;
	private $default_sort_column = null;
	private $default_sort_direction = null;
	private $empty_message = null;
	private $paging_message = null;

	public function __construct()
	{
		$this->name = 'statsordersunpaid';
		$this->tab = 'analytics_stats';
		$this->version = '1.0';
		$this->author = 'zimmer-media-office';
		$this->need_instance = 0;

		parent::__construct();

		$this->default_sort_column = 'date_add';
		$this->default_sort_direction = 'ASC';
		$this->empty_message = $this->l('An empty record-set was returned.');
		$this->paging_message = sprintf($this->l('Displaying %1$s of %2$s'), '{0} - {1}', '{2}');

		$this->columns = array(
			array(
				'id' => 'id_order',
				'header' => $this->l('Order ID'),
				'dataIndex' => 'id_order',
				'align' => 'right'
			),
			array(
				'id' => 'reference',
				'header' => $this->l('Order Number'),
				'dataIndex' => 'reference',
				'align' => 'right'
			),
			array(
				'id' => 'order_date',
				'header' => $this->l('Order Date'),
				'dataIndex' => 'order_date',
				'align' => 'center'
			),
			array(
				'id' => 'order_state',
				'header' => $this->l('Order State'),
				'dataIndex' => 'order_state',
				'align' => 'right'
			),
			array(
				'id' => 'totalpaidtaxincl',
				'header' => $this->l('Total paid Tax incl'),
				'dataIndex' => 'totalpaidtaxincl',
				'align' => 'right'
			),
			array(
				'id' => 'lastname',
				'header' => $this->l('Lastname'),
				'dataIndex' => 'lastname',
				'align' => 'right'
			),
			array(
				'id' => 'firstname',
				'header' => $this->l('Firstname'),
				'dataIndex' => 'firstname',
				'align' => 'right'
			)
		);

		$this->displayName = $this->l('Unpaid Orders');
		$this->description = $this->l('Adds a list of the unpaid orders to the Stats dashboard.');
		$this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
	}

	public function install()
	{
		return (parent::install() && $this->registerHook('AdminStatsModules'));
	}

	public function hookAdminStatsModules($params)
	{
		$engine_params = array(
			'id' => 'id_product',
			'title' => $this->displayName,
			'columns' => $this->columns,
			'defaultSortColumn' => $this->default_sort_column,
			'defaultSortDirection' => $this->default_sort_direction,
			'emptyMessage' => $this->empty_message,
			'pagingMessage' => $this->paging_message
		);

		if (Tools::getValue('export'))
			$this->csvExport($engine_params);

		return '<div class="panel-heading">'.$this->displayName.'</div>
		'.$this->engine($engine_params).'
		<a class="btn btn-default export-csv" href="'.Tools::safeOutput($_SERVER['REQUEST_URI'].'&export=1').'">
			<i class="icon-cloud-upload"></i> '.$this->l('CSV Export').'
		</a>';
		
		return $this->html;
	}

	public function getData()
	{
		$currency = new Currency(Configuration::get('PS_CURRENCY_DEFAULT'));

		$this->query = 'SELECT oi.id_order, oi.reference, ROUND(oi.total_paid_tax_incl,2) as totalpaidtaxincl, 
		DATE_FORMAT(oi.date_add, \'%d.%m.%Y\') as order_date, o.current_state, os.name as order_state, oi.id_customer, c.firstname, c.lastname
		from  '._DB_PREFIX_.'orders oi
                JOIN  '._DB_PREFIX_.'orders o on oi.id_order = o.id_order
                JOIN  '._DB_PREFIX_.'customer c on o.id_customer = c.id_customer 
                JOIN  '._DB_PREFIX_.'order_state_lang os ON o.current_state = os.id_order_state
		WHERE os.id_order_state = 1 OR os.id_order_state = 3 OR os.id_order_state = 8 OR os.id_order_state = 9 OR os.id_order_state = 10 OR 
		os.id_order_state = 11 OR os.id_order_state = 13 OR os.id_order_state = 16 AND os.id_lang = 1
		ORDER by oi.date_add ASC
		';
		
		
		
		

		if (Validate::IsName($this->_sort))
		{
			$this->query .= ' ORDER BY `'.bqSQL($this->_sort).'`';
			if (isset($this->_direction) && Validate::isSortDirection($this->_direction))
				$this->query .= ' '.$this->_direction;
		}


		$values = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS($this->query);
		foreach ($values as &$value)
		{
			$value['totalpaidtaxincl'] = Tools::displayPrice($value['totalpaidtaxincl'], $currency);
		}
		unset($value);

		$this->_values = $values;
		$this->_totalCount = Db::getInstance(_PS_USE_SQL_SLAVE_)->getValue('SELECT FOUND_ROWS()');
	}
}
